From 339786919567a92b8f0c363837c1f40058b90ddd Mon Sep 17 00:00:00 2001
From: LmeSzinc <37934724+LmeSzinc@users.noreply.github.com>
Date: Sun, 10 Sep 2023 01:54:17 +0800
Subject: [PATCH] Add: Replace Alas with SRC on frontend
---
assets/gui/icon/alas.svg | 124 ++++++++++++++++++++++++++++++++++++++-
module/webui/app.py | 8 +--
module/webui/base.py | 2 +-
3 files changed, 128 insertions(+), 6 deletions(-)
diff --git a/assets/gui/icon/alas.svg b/assets/gui/icon/alas.svg
index 308a869e0..18ce1e837 100644
--- a/assets/gui/icon/alas.svg
+++ b/assets/gui/icon/alas.svg
@@ -1 +1,123 @@
-
\ No newline at end of file
+
diff --git a/module/webui/base.py b/module/webui/base.py
index 29619551b..9727ec5c8 100644
--- a/module/webui/base.py
+++ b/module/webui/base.py
@@ -90,7 +90,7 @@ class Frame(Base):
"header",
[
put_html(Icon.ALAS).style("--header-icon--"),
- put_text("Alas").style("--header-text--"),
+ put_text("SRC").style("--header-text--"),
put_scope("header_status"),
put_scope("header_title"),
],
diff --git a/module/webui/app.py b/module/webui/app.py
index d916b22ca..5d8cb993c 100644
--- a/module/webui/app.py
+++ b/module/webui/app.py
@@ -1109,9 +1109,9 @@ class AlasGUI(Frame):
# show something
put_markdown(
"""
- Alas is a free open source software, if you paid for Alas from any channel, please refund.
- Alas 是一款免费开源软件,如果你在任何渠道付费购买了Alas,请退款。
- Project repository 项目地址:`https://github.com/LmeSzinc/AzurLaneAutoScript`
+ SRC is a free open source software, if you paid for SRC from any channel, please refund.
+ SRC 是一款免费开源软件,如果你在任何渠道付费购买了SRC,请退款。
+ Project repository 项目地址:`https://github.com/LmeSzinc/StarRailCopilot`
"""
).style("text-align: center")
@@ -1131,7 +1131,7 @@ class AlasGUI(Frame):
def run(self) -> None:
# setup gui
- set_env(title="Alas", output_animation=False)
+ set_env(title="SRC", output_animation=False)
add_css(filepath_css("alas"))
if self.is_mobile:
add_css(filepath_css("alas-mobile"))